DirectprintPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • DirectprintPlatform
Implementers

Constructors

DirectprintPlatform()
Constructs a DirectprintPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
print(String printer, String job, Uint8List data) → Future<String?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ DirectprintPlatform
The default instance of DirectprintPlatform to use.
getter/setter pair